@@ -52,7 +52,8 @@ Station = [{}, {}, {}, {}, {}, {}, {}, {}]
 LINE_STOP = 0
 LINE_DIRECTIONS = 1
 LINE_GROUPS = 2
-Line = [{}, {}, {}]
+LINE_FULL = 3
+Line = [{}, {}, {}, {}]
 
 station_from = ""
 station_to = ""
@@ -105,72 +106,13 @@ def cleanString(string):
 
 
 ###############################################################################
-# Populate the station and line data arrays (load from file or pickle)
+# Populate the station and line data arrays (load from pickle)
 
 if os.path.exists(DATA_FILE):
 	[Station, Line] = cPickle.load(open(DATA_FILE, 'r'))
-	FullLine = {}
-	for superline in Line[LINE_GROUPS]:
-		for line_1 in Line[LINE_GROUPS][superline]:
-			FullLine[line_1] = list(Line[LINE_STOP][line_1])
-			for line_2 in Line[LINE_GROUPS][superline]:
-				if Line[LINE_STOP][line_1][0] == Line[LINE_STOP][line_2][-1]:
-					FullLine[line_1][0:0] = list(Line[LINE_STOP][line_2][:-1])
-				if Line[LINE_STOP][line_1][-1] == Line[LINE_STOP][line_2][0]:
-					FullLine[line_1][-1:-1] = list(Line[LINE_STOP][line_2][1:])
 else:
-	if not os.path.exists(DATA_DIR):
-		print "Error: Neither data file nor database found."
-		exit()
-	f = open(DATA_DIR + STATIONS_FILE)
-	for station in f.readlines():
-		station = str.split(str.split(station, '#')[0].strip(), '\t')
-		name = station[0]
-		station[0] = cleanString(station[0]).replace(',', '')
-		Station[STATION_NAME][station[0]] = name
-		Station[STATION_HASH][station[0]] = soundex(name)
-		Station[STATION_ZONES][station[0]] = []
-		Station[STATION_LINES][station[0]] = []
-		Station[STATION_DISTANCE][station[0]] = [INFINITY, False]
-		for zone in str.split(station[1], ';'):
-			Station[STATION_ZONES][station[0]].append(int(zone))
-
-	TubeLines = os.listdir(DATA_DIR)
-	for line in TubeLines:
-		if line != STATIONS_FILE:
-			Line[LINE_STOP][line] = []
-			Line[LINE_DIRECTIONS][line] = []
-			Station[STATION_TIMES][line] = []
-			f = open(DATA_DIR + line)
-			for stop in f.readlines():
-				stop = str.split(stop, '#')[0].strip()
-				if len(Line[LINE_DIRECTIONS][line]) == 0:
-					directions = str.split(str.strip(stop), '\t')
-					if len(directions) < 1:
-						directions = [""]
-					if len(directions) < 2:
-						directions.append("")
-					Line[LINE_DIRECTIONS][line] = directions
-				else:
-					stop = str.strip(str.lower(stop))
-					if stop != "":
-						stop = str.split(stop, '\t')
-						Line[LINE_STOP][line].append(stop[0])
-						if len(stop) > 1:
-							Station[STATION_TIMES][line].append(int(stop[1]))
-						else:
-							Station[STATION_TIMES][line].append(DEFAULT_TIME)
-						Station[STATION_LINES][stop[0]].append(line)
-			f.close()
-
-	for line in Line[LINE_STOP].keys():
-		superline = line.partition("(")[0].strip()
-		if not Line[LINE_GROUPS].has_key(superline):
-			Line[LINE_GROUPS][superline] = [superline]
-		if superline != line:
-			Line[LINE_GROUPS][superline].append(line)
-
-	cPickle.dump([Station, Line], open(DATA_FILE, 'w'))
+	print "Error: Data file not found."
+	exit()
 
 
 ###############################################################################
@@ -204,10 +146,10 @@ def get_closures():
 			if Line[LINE_GROUPS].has_key(part[0]):
 				for line in Line[LINE_GROUPS][part[0]]:
 					try:
-						closed_from = min(FullLine[line].index(cleanString(part[1])), FullLine[line].index(cleanString(part[2])))
-						closed_to = max(FullLine[line].index(cleanString(part[1])), FullLine[line].index(cleanString(part[2])))
+						closed_from = min(Line[LINE_FULL][line].index(cleanString(part[1])), Line[LINE_FULL][line].index(cleanString(part[2])))
+						closed_to = max(Line[LINE_FULL][line].index(cleanString(part[1])), Line[LINE_FULL][line].index(cleanString(part[2])))
 						for i in range(closed_to - closed_from):
-							idx = Line[LINE_STOP][line].index(FullLine[line][i + closed_from])
+							idx = Line[LINE_STOP][line].index(Line[LINE_FULL][line][i + closed_from])
 							if len(part) == 3:
 								Station[STATION_TIMES][line][idx] = INFINITY
 							else:
@@ -463,16 +405,8 @@ def main():
 		image = gtk.Image()
 		image_event = gtk.EventBox()
 		image_event.add_events(gtk.gdk.BUTTON_PRESS_MASK | gtk.gdk.KEY_PRESS_MASK)
+		pixmap,mask = pixbuf.render_pixmap_and_mask()
 		if route.plan != None:
-			pixbuf = mapbuf
-			pixmap,mask = pixbuf.render_pixmap_and_mask()
-			cm = pixmap.get_colormap()
-			red = cm.alloc_color('red')
-			black = cm.alloc_color('black')
-			white = cm.alloc_color('white')
-			gc_red = pixmap.new_gc(foreground=red,line_width=5)
-			gc_black = pixmap.new_gc(foreground=black,line_width=5)
-			gc_white = pixmap.new_gc(foreground=white,line_width=9)
 			for i in range(len(route.plan[0])):
 				stop = route.plan[0][i]
 				if len(Station[STATION_COORDS][stop]) == 4:
@@ -577,8 +511,8 @@ def main():
 								if len(Station[STATION_COORDS][stop]) == 4:
 									data.scroll_to(int((Station[STATION_COORDS][stop][0] + Station[STATION_COORDS][stop][2])/2*MAP_SCALE), int((Station[STATION_COORDS][stop][1] + Station[STATION_COORDS][stop][3])/2*MAP_SCALE))
 									bScrolled = True
-			if not bScrolled:
-				data.scroll_to(event.x, event.y)
+			#if not bScrolled:
+			#	data.scroll_to(event.x, event.y)
 		widget.oldtime = event.time
 
 	def showdialog(title, route):
@@ -626,6 +560,15 @@ def main():
 	mapbuf = mapbuf.scale_simple(MAP_SCALE*mapbuf.get_width(), MAP_SCALE*mapbuf.get_height(), gtk.gdk.INTERP_NEAREST)
 	map_x = mapbuf.get_width()/2
 	map_y = mapbuf.get_height()/2
+	pixbuf = mapbuf
+	pixmap,mask = pixbuf.render_pixmap_and_mask()
+	cm = pixmap.get_colormap()
+	red = cm.alloc_color('red')
+	black = cm.alloc_color('black')
+	white = cm.alloc_color('white')
+	gc_red = pixmap.new_gc(foreground=red,line_width=5)
+	gc_black = pixmap.new_gc(foreground=black,line_width=5)
+	gc_white = pixmap.new_gc(foreground=white,line_width=9)
 
 	win = hildon.StackableWindow()
 	win.set_title("Tubes")
